
// Moteurs
#define PIN_9 9
#define PIN_10 10

// Capteurs ultrasons
const byte TRIGGER_PIN = 2; // Broche TRIGGER
const byte ECHO_PIN = 3;    // Broche ECHO

// Accelerometre
const int x1pin = A0;                  
const int y1pin = A1;                  
const int z1pin = A2;

float speed = 0;
float orientation = 0.0;


int index = 0;

/* Constantes pour le timeout */
const unsigned long MEASURE_TIMEOUT = 25000UL; // 25ms = ~8m à 340m/s

/* Vitesse du son dans l'air en mm/us */
const float SOUND_SPEED = 340.0 / 1000; 

void setup() {    

    Serial.begin(9600);
    
    pinMode(PIN_9, OUTPUT);
    digitalWrite(PIN_9, LOW);
    
    pinMode(PIN_10, OUTPUT);
    digitalWrite(PIN_10, LOW);
    
    pinMode(TRIGGER_PIN, OUTPUT);
    digitalWrite(TRIGGER_PIN, LOW); // La broche TRIGGER doit être à LOW au repos
    pinMode(ECHO_PIN, INPUT);

  }

void loop() {

  if(index == 0){
    delay(5000);
    index ++;
  }

  /* --- Partie capteur ultra-son --- */
  digitalWrite(TRIGGER_PIN, HIGH);
  delayMicroseconds(10);
  digitalWrite(TRIGGER_PIN, LOW);

  long measure = pulseIn(ECHO_PIN, HIGH, MEASURE_TIMEOUT);
   
  /* 3. Calcul la distance à partir du temps mesuré */
  float distance_mm = measure / 2.0 * SOUND_SPEED;
   
  /* --- Partie Capteur accelerometre --- */
  int intX1pin = analogRead(x1pin);
  int intY1pin = analogRead(y1pin);
  int intZ1pin = analogRead(z1pin);
  
  /* --- Partie mouvement automatique --- */
  if(distance_mm > 500 || distance_mm == 0){
    goForward();
  } else {
    turnLeft();
    turnLeft();  
  }


  /* --- Handle orientation --- */
  if(orientation > 360){
    orientation = orientation - 360;
  }
  else if(orientation < 0)
  {
    orientation = 360 + orientation; 
  }
  /* --- Sending data to serial port --- */
  String buf;
  
  buf += F("{\"distance\": ");
  buf += String(distance_mm/1000);
  buf += ", ";
  
  buf += F("\"orientation\": ");
  buf += String(orientation);
  buf += ", ";

  buf += F("\"speed\": ");
  buf += String(speed);
 
  buf += "}";

  Serial.println(buf);

  delay(960);
    
}

/* --- Partie fonction de mouvement --- */
void goForward(){
  speed = 0.1666666;
  orientation -= 1;
  digitalWrite(PIN_9, HIGH);
  digitalWrite(PIN_10, HIGH);  
}

void turnRight(){
    speed = 0.01666666;
    orientation += 22 ;
    digitalWrite(PIN_9, HIGH);
    digitalWrite(PIN_10, LOW);
}

void turnLeft(){
    speed = 0.01666666;
    orientation -= 22  ;
    digitalWrite(PIN_9, LOW);
    digitalWrite(PIN_10, HIGH);
}

void StopIt(){
  digitalWrite(PIN_9, LOW);
  digitalWrite(PIN_10, LOW);  
}